<!-- docs/_sidebar.md -->
<!-- markdownlint-disable first-line-h1 -->

- [**Getting started**](README.md)
  - [Quick start](quickstart.md)
  - [Setting up your local LaTeX](config_latex.md)
  - [Usage](usage.md)

- Writing a Test
  - [Test File Syntax](syntax_yaml.md)
  - [Questions Syntax](syntax_questions.md)
  - [Header Section](syntax_header.md)
  - [Markdown Syntax](syntax_md.md)

- Customisation 
  - [Configuration File](config_files.md)
  - [Writing Your Own Target](targets.md)
  - [Writing Your Own Rendering Templates](writing_templates.md)
  
- [Changelog](changelog.md)







